# Craftr Documentation

Version: 2.0.0.dev3

- [Getting Started](getting-started.md)
- [Package documentation](package.md)
- [Built-ins documentation](builtins.md)
- [Config documentation](config.md)
- [Writing Target generators](generators.md)
- [Using external files/source archives](loaders.md)

Other:

- [FAQ](faq.md)
- [Transition from Craftr 1](transition.md)
